%--------------------------------------------------------------------------
%   Copyright (c) 2020 Princeton Satellite Systems
%   All rights reserved.
%--------------------------------------------------------------------------

close all;clear;

folderPrefix = './CONVERTME/';
folder = './20200205-162636/';
postfix = '-20200205-162636.hdf5';

figure();
subplot(2,1,1);
hold on;
xlabel('Time (ms)');
legendString = {};

diagnostic = 'interferometer';
traceName = 'atan';
fileName = strcat(folderPrefix,folder,diagnostic,'/',diagnostic,'-',traceName,postfix);

[n,tn] = LoadHDF5(fileName);

n = (n - mean(n(1:10)))*2.1e12/(pi/2)*(8/5);
plot(tn*1e3,n*1e-12);
legendString = [legendString,{'Single-shot line-integrated density (10^{12}/cc)'}];

grid on;grid minor;
legend(legendString);
title(folder);

w = (1:1:100)'*1e3*2*pi;
subplot(2,1,2);
nConv = WaveletMorlet(tn',n',w,10);
surf(tn,w/2/pi,nConv)
shading interp;view(0,90);
%colorbar
xlabel('Time (seconds)');ylabel('Freq (Hz)');

saveas(gcf,'InterferometerWaveletAnalysis.pdf');

function [x,t] = LoadHDF5(fileName)
fileInfo = h5info(fileName);
attributeNames = {fileInfo.Datasets.Attributes.Name};
attributeValues = {fileInfo.Datasets.Attributes.Value};

for i = 1:numel(attributeNames)
  if strcmp(attributeNames{i} ,'horizontal_interval')
    dt = attributeValues{i};
  end
  if strcmp(attributeNames{i} ,'horizontal_offset')
    deltat = attributeValues{i};
  end
end

x = h5read(fileName,'/waveform');

t = (1:numel(x))*dt + deltat;
end