%--------------------------------------------------------------------------
%   Copyright (c) 2019 Princeton Satellite Systems
%   All rights reserved.
%--------------------------------------------------------------------------

% As I found on 2019/07/10:
% MATLAB does not read HDF5 files created with HDF5 v1.10. You must convert
% them.
% You must install the HDF5 utils on your computer and run them on the
% LOCALLY SAVED HDF5 files. On a mac this went thus:
% brew install hdf5
% cd Desktop/local-20190709/interferometer/HDF5sConverted/
% h5format_convert interferometer-x-20190709-103807.hdf5

close all;clear;

folder = './CONVERTME/20200205-162636/';
postfix = '-20200205-162636.hdf5';

figure();
hold on;
xlabel('Time (ms)');
legendString = {};

diagnostic = 'interferometer';
traceName = 'atan';
fileName = strcat(folder,diagnostic,'/',diagnostic,'-',traceName,postfix);

[n,tn] = LoadHDF5(fileName);
%[n,tn] = DecimateNTimes(n,tn,4);

n = (n - mean(n(1:10)))*2.1e12/(pi/2)*(8/5);
plot(tn*1e3,n*1e-12);
legendString = [legendString,{'Single-shot line-integrated density (10^{12}/cc)'}];

grid on;grid minor;
legend(legendString);
title(folder);

function [x,t] = DecimateNTimes(x,t,N)
for inds = 1:N
  x = (x(1:2:end-1)+x(2:2:end))/2;
  t = (t(1:2:end-1)+t(2:2:end))/2;
end
end

function [x,t] = LoadHDF5(fileName)
fileInfo = h5info(fileName);
attributeNames = {fileInfo.Datasets.Attributes.Name};
attributeValues = {fileInfo.Datasets.Attributes.Value};

for i = 1:numel(attributeNames)
  if strcmp(attributeNames{i} ,'horizontal_interval')
    dt = attributeValues{i};
  end
  if strcmp(attributeNames{i} ,'horizontal_offset')
    deltat = attributeValues{i};
  end
end

x = h5read(fileName,'/waveform');

t = (1:numel(x))*dt + deltat;
end