%--------------------------------------------------------------------------
%   Copyright (c) 2020 Princeton Satellite Systems
%   All rights reserved.
%--------------------------------------------------------------------------
% X-ray inversion tools V 4.2 must be loaded. Examples
% On the cluster:
% addpath('/p/pfrc/tools/xray_inversion/cswanson-V4.2/analysis/');
% On Dr Charles's macbook:
% addpath('/Users/cswanson/local-inversion/cswanson-V4.2/analysis/');

close all;clear;
boolSave = true;

directory = '../spectra/';
files = {
  '01-SDD3-CC-midPoint-ap2-200ns-noise.mca'
  '02-SDD1-CC-radialScan-3.5divs-200ns-noise.mca'
  '03-SDD3-ap2-RMF.mca'
  '04-SDD1-0divs-RMF.mca'
  '05-SDD3-ap2-5ms.mca'
  %  '05-SDD3-ap3-5ms.mca'
  '06-SDD1-0divs-5ms.mca'
  '07-SDD3-ap2-70kW.mca'
  '08-SDD1-0divs-70kW.mca'
  '09-SDD3-ap2-72kW.mca'
  '10-SDD1-0divs-72kW.mca'
  '11-SDD3-ap1-72kW.mca'
  '12-SDD1-0divs.mca'
  '13-SDD1-0divs-drift.mca'
  '14-SDD1-1divs.mca'
  '15-SDD1-2divs.mca'
%  '15-SDD3-ap1-drift.mca'
  '16-SDD1-3divs.mca'
  '17-SDD1-4divs.mca'
  '18-SDD1-5divs.mca'
  '19-SDD1-3divs.mca'
  '20-SDD1-4divs-reshield.mca'
  '21-SDD1-8divs.mca'
  '22-SDD1-7divs.mca'
  '23-SDD1-6divs.mca'
  '24-SDD1-5divs.mca'
  '25-SDD3-ap1-drift.mca'
  '26-SDD1-7divs.mca'
  '27-SDD1-8divs-quickScan.mca'
  '28-SDD1-7divs-quickScan.mca'
  '29-SDD1-6divs-quickScan.mca'
  '30-SDD1-5divs-quickScan.mca'
  '31-SDD1-4divs-quickScan.mca'
  '32-SDD1-3divs-quickScan.mca'
  '33-SDD1-2divs-quickScan.mca'
  '34-SDD1-8divs-quickScan2.mca'
  '35-SDD1-7divs-quickScan2.mca'
  '36-SDD1-8divs-quickScan3.mca'
  '37-SDD1-7divs-quickScan3.mca'
  '38-SDD1-6divs-quickScan3.mca'
  '39-SDD1-5divs-quickScan3.mca'
  '40-SDD1-4divs-quickScan3.mca'
  '41-SDD1-3divs-quickScan3.mca'
  '42-SDD1-2divs-quickScan3.mca'
  '43-SDD1-1divs-quickScan3.mca'
  '44-SDD3-ap2-5ms.mca'
  '45-SDD1-5divs-5ms.mca'
  '46-SDD3-ap2-7ms.mca'
  '47-SDD1-5divs-7ms.mca'
  '48-SDD3-ap2-lessPressure.mca'
  '49-SDD1-5divs-lessPressure.mca'};

experiments = {[12:26],[27:33],[36:43]};
expNames = {'Initial scan','Quickscan','Quickscan 3'};
for expInd = 1:3
batchQuants = [];
figure('Position', [100, 100, 600, 400]);
hold on;
set(gca,'yscale','log');
grid on;grid minor;
figFont = 12;figLineWidth = 1;
figTitle = {};
legendCell = {};
for fileInd = experiments{expInd}
  file = files{fileInd};
  MCA = ParseMCA(strcat(directory,file));
  MCA = MCA.SetECal(MCA);
  fprintf('%s: %d slow, %d fast \n',MCA.fileName,sum(MCA.counts),MCA.fastCounts);
  div = WhichDiv(MCA.fileName);
  if div>=0 % && sum(MCA.counts)>MCA.fastCounts*3
    dutyFactor = LoadMetadata(MCA,'Duty factor');
    mountStr = LoadMetadata(MCA,'Mount');
    mount = LoadMount(LoadMetadata(MCA,'Mount'));
    mPlot = MCA.counts/MCA.ECal.slope/MCA.timeAccum/dutyFactor/mount.V;
    plot(MCA.ECal.Ex,mPlot);
    localLegend = sprintf('spect. %s, %ddivs',file(1:2), div);
    legendCell = [legendCell,localLegend];
    batchQuants = [batchQuants; str2num(file(1:2)) div sum(MCA.counts)/MCA.timeAccum/dutyFactor/mount.V]; % spectrum number, divisions, volumetric count rate
  end
  
  
  
end

figTitle={MCA.dateTime,sprintf('%s, Spectra %d - %d',expNames{expInd},experiments{expInd}(1),experiments{expInd}(end))};
legend(legendCell);
axis([0 1000 2e2 5e6]);
xlabel('Energy (eV)','FontSize',figFont);
ylabel('Volumetric spectral X-Ray Rate (/cc/eV/s)','FontSize',figFont);
set(gca,'FontSize',figFont,'LineWidth',figLineWidth);
title(figTitle,'FontSize',figFont);
if boolSave
  saveas(gcf,sprintf('%sSpectra.pdf',expNames{expInd}));
end

figure('Position', [100, 100, 600, 400]);
hold on;
set(gca,'yscale','lin');
grid on;grid minor;
figFont = 12;figLineWidth = 1;
plot(batchQuants(:,2)+0.5,batchQuants(:,3),'o','LineWidth',3);
xlabel('Radial intercept (cm)');
ylabel('Volumetric count rate (/cc/s)');
set(gca,'FontSize',figFont,'LineWidth',figLineWidth);
title(figTitle,'FontSize',figFont);
if boolSave
  saveas(gcf,sprintf('%sCountRates.pdf',expNames{expInd}));
end
end

return


function div = WhichDiv(inString)
div = -1;
for which=0:8
  if contains(inString,sprintf('%ddivs',which))
    div = which;
  end
end
end
