%--------------------------------------------------------------------------
%   Copyright (c) 2020 Princeton Satellite Systems
%   All rights reserved.
%--------------------------------------------------------------------------
% X-ray inversion tools V 4.2 must be loaded. Examples
% On the cluster:
% addpath('/p/pfrc/tools/xray_inversion/cswanson-V4.2/analysis/');
% On Dr Charles's macbook:
% addpath('/Users/cswanson/local-inversion/cswanson-V4.2/analysis/');

close all;clear;
boolSave = true;

directory = '../spectra/';
files = {
  '12-SDD1-0divs.mca'
  '13-SDD1-0divs-drift.mca'
  '14-SDD1-1divs.mca'
  '15-SDD1-2divs.mca'
  '16-SDD1-3divs.mca'
  '17-SDD1-4divs.mca'
  '18-SDD1-5divs.mca'
  '19-SDD1-3divs.mca'
  '20-SDD1-4divs-reshield.mca'
  '21-SDD1-8divs.mca'
  '22-SDD1-7divs.mca'
  '23-SDD1-6divs.mca'
  '24-SDD1-5divs.mca'
  '26-SDD1-7divs.mca'
  '27-SDD1-8divs-quickScan.mca'
  '28-SDD1-7divs-quickScan.mca'
  '29-SDD1-6divs-quickScan.mca'
  '30-SDD1-5divs-quickScan.mca'
  '31-SDD1-4divs-quickScan.mca'
  '32-SDD1-3divs-quickScan.mca'
  '33-SDD1-2divs-quickScan.mca'
  '34-SDD1-8divs-quickScan2.mca'
  '35-SDD1-7divs-quickScan2.mca'
  '36-SDD1-8divs-quickScan3.mca'
  '37-SDD1-7divs-quickScan3.mca'
  '38-SDD1-6divs-quickScan3.mca'
  '39-SDD1-5divs-quickScan3.mca'
  '40-SDD1-4divs-quickScan3.mca'
  '41-SDD1-3divs-quickScan3.mca'
  '42-SDD1-2divs-quickScan3.mca'
  '43-SDD1-1divs-quickScan3.mca'
  };

spectNum = [];
moment = [];
momentErr = [];
figure('Position', [100, 100, 600, 400]);
hold on;
grid on;grid minor;
figFont = 12;figLineWidth = 1;
figTitle = {};
legendCell = {};
for fileInd = 1:numel(files)
  file = files{fileInd};
  MCA = ParseMCA(strcat(directory,file));
  MCA = MCA.SetECal(MCA);
  fprintf('%s: %d slow, %d fast \n',MCA.fileName,sum(MCA.counts),MCA.fastCounts);
  if sum(MCA.counts)>0
    spectNum = [spectNum str2num(file(1:2))];
    Et = min(MCA.ECal.Ex(MCA.counts>0));
    Emom = sum(MCA.counts(MCA.ECal.Ex>Et).*(MCA.ECal.Ex(MCA.ECal.Ex>Et)-Et))/sum(MCA.counts(MCA.ECal.Ex>Et));
    moment = [moment Emom];
    momentErr = [momentErr sqrt(sum(MCA.counts))];
  end
end

errorbar(spectNum,moment,moment./momentErr,'.');

figTitle={sprintf('%s - %s',files{1},files{end})};
%legend(legendCell);
xlabel('Spectrum Number','FontSize',figFont);
ylabel('Average energy above threshold (eV)','FontSize',figFont);
set(gca,'FontSize',figFont,'LineWidth',figLineWidth);
title(figTitle,'FontSize',figFont);
if boolSave
  saveas(gcf,'RadialScanSlope.pdf');
end


return


function div = WhichDiv(inString)
div = -1;
for which=0:8
  if contains(inString,sprintf('%ddivs',which))
    div = which;
  end
end
end
