%--------------------------------------------------------------------------
%   Copyright (c) 2016 - 2018 Charles Swanson, Princeton Plasma Physics Lab
%   Copyright (c) 2019 Princeton Satellite Systems
%   All rights reserved.
%--------------------------------------------------------------------------
% This file is copied into a local analysis directory from
% xray_inversion/cswanson-V4.2/analysis/LocalFiles 
% This file performs a forward-fit x-ray spectrum analysis: It plots the
% volumetric spectral count rate against a fit to a spectrum produced by a
% Maxwellian EEDF and tabulates the fit density and temperature of that
% Maxwellian. It performs analyses specified in ForwardFitParameters.csv.
% If this file does not exist, it creates one with the default fields.

% On the cluster, x-ray inversion tools V 4.2 must be loaded:
% addpath('/p/pfrc/tools/xray_inversion/cswanson-V4.2/analysis/');

close all;clear;

if ~exist('ForwardFitParameters.csv','file')
  out = {'% ForwardFitParameters:'};
  out = AppendAndPadCells(out,{'% This file performs a forward-fit x-ray spectrum analysis: It plots the volumetric spectral count rate against a fit to a spectrum produced by a Maxwellian EEDF and tabulates the fit density and temperature of that Maxwellian.'});
  out = AppendAndPadCells(out,{'% This line is applied to all successive lines:'});
  out = AppendAndPadCells(out,{'Apply to successive','','Path','../spectra/','Channels','[10:1024]','Window model','NIST default thicknesses','Solver tolerance','1e-6','Output directory','ForwardFitOutput','Comment','-','Plot','Yes','Save','Yes','Save plot','Yes'});
  out = AppendAndPadCells(out,{'% An example input line is (remove % sign):'});
  out = AppendAndPadCells(out,{'% File','','Noise file'});
  writecell(out,'ForwardFitParameters.csv');
  
  fprintf('ForwardFitParameters.csv file has been created. \nPlease populate it with analyses to perform \n');
  beep;
  return
end

forwardFitParameters = readcell('ForwardFitParameters.csv');
secondary = {};

for analysisIndex = 1:size(forwardFitParameters,1)
  if strcmp(forwardFitParameters(analysisIndex,1),'Apply to successive')
    secondary = forwardFitParameters(analysisIndex,:);
  else
    controlString = forwardFitParameters(analysisIndex,:);
    %controlString(2)
    ForwardFit([controlString,secondary]);
  end
end


