%--------------------------------------------------------------------------
%   Copyright (c) 2016 - 2018 Charles Swanson, Princeton Plasma Physics Lab
%   Copyright (c) 2019 Princeton Satellite Systems
%   All rights reserved.
%--------------------------------------------------------------------------
% This file is copied into a local analysis directory from
% xray_inversion/cswanson-V4.2/analysis/LocalFiles 
% This file performs a basic x-ray spectrum analysis: It plots the
% volumetric spectral count rate and tabulates the total spectral count
% rate of the MCA files listed in AnalysisParameters.csv. If this file does
% not exist, it creates one with the default fields.

% On the cluster, x-ray inversion tools V 4.2 must be loaded:
% addpath('/p/pfrc/tools/xray_inversion/cswanson-V4.2/analysis/');

close all;clear;

if ~exist('AnalysisParameters.csv','file')
  out = {'% AnalysisParameters:'};
  out = AppendAndPadCells(out,{'% This file performs a basic x-ray spectrum analysis: It plots the volumetric spectral count rate and tabulates the total spectral count'});
  out = AppendAndPadCells(out,{'% This line is applied to all successive lines:'});
  out = AppendAndPadCells(out,{'Apply to successive','','Path','../spectra/','Channels','[10:1024]','Window model','NIST default thicknesses','Solver tolerance','1e-6','Output directory','SpectraOutput','Comment','-','Plot','Yes','Save','Yes','Save plot','Yes'});
  out = AppendAndPadCells(out,{'% An example input line is (remove % sign):'});
  out = AppendAndPadCells(out,{'% File'});
  writecell(out,'AnalysisParameters.csv');
  
  fprintf('AnalysisParameters.csv file has been created. \nPlease populate it with analyses to perform \n');
  beep;
  return
end

analysisParameters = readcell('AnalysisParameters.csv');
secondary = {};

for analysisIndex = 1:size(analysisParameters,1)
  if strcmp(analysisParameters(analysisIndex,1),'Apply to successive')
    secondary = analysisParameters(analysisIndex,:);
  else
    controlString = analysisParameters(analysisIndex,:);
    XRaySpectrum([controlString,secondary]);
  end
end


